@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2008 Sun Microsystems Inc.
+# Copyright 2004-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -23,7 +23,7 @@ as its speech server, or it can feel free to create one of its own."""
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import logging
@@ -38,6 +38,8 @@ import keynames
 import orca
 import orca_state
 import settings
+import sound
+import speech_generator
 
 from acss import ACSS
 from orca_i18n import _           # for gettext support
@@ -137,20 +139,35 @@ def sayAll(utteranceIterator, progressCallback):
             debug.println(debug.LEVEL_INFO, logLine)
             log.info(logLine)
 
-def speak(text, acss=None, interrupt=True):
-    """Speaks all queued text immediately.  If text is not None,
-    it is added to the queue before speaking.
+def _speak(text, acss, interrupt):
+    """Speaks the individual string using the given ACSS."""
 
-    Arguments:
-    - text:      optional text to add to the queue before speaking
-    - acss:      acss.ACSS instance; if None,
-                 the default voice settings will be used.
-                 Otherwise, the acss settings will be
-                 used to augment/override the default
-                 voice settings.
-    - interrupt: if True, stops any speech in progress before
-                 speaking the text
-    """
+    if settings.speakMultiCaseStringsAsWords:
+        text = _processMultiCaseString(text)
+    if orca_state.activeScript and orca_state.usePronunciationDictionary:
+        text = orca_state.activeScript.adjustForPronunciation(text)
+    if settings.speakMultiCaseStringsAsWords:
+        text = _processMultiCaseString(text)
+
+    logLine = "SPEECH OUTPUT: '" + text + "'"
+    extraDebug = ""
+    if acss in settings.voices.values():
+        for key in settings.voices:
+            if acss == settings.voices[key]:
+                if key != settings.DEFAULT_VOICE:
+                    extraDebug = " voice=%s" % key
+                break
+    debug.println(debug.LEVEL_INFO, logLine + extraDebug)
+    log.info(logLine + extraDebug)
+
+    if _speechserver:
+        _speechserver.speak(text, __resolveACSS(acss), interrupt)
+
+
+def speak(content, acss=None, interrupt=True):
+    """Speaks the given content.  The content can be either a simple
+    string or an array of arrays of objects returned by a speech
+    generator."""
 
     # We will not interrupt a key echo in progress.
     #
@@ -161,19 +178,55 @@ def speak(text, acss=None, interrupt=True):
     if settings.silenceSpeech:
         return
 
-    if settings.speakMultiCaseStringsAsWords:
-        text = _processMultiCaseString(text)
-    if orca_state.activeScript and orca_state.usePronunciationDictionary:
-        text = orca_state.activeScript.adjustForPronunciation(text)
-    if settings.speakMultiCaseStringsAsWords:
-        text = _processMultiCaseString(text)
+    subString = None
+    if isinstance(content, basestring):
+        subString = content
+    elif isinstance(content, list):
+        for element in content:
+            if isinstance(element, basestring):
+                if subString:
+                    subString += " " + element
+                else:
+                    subString = element
+            elif isinstance(element, speech_generator.Pause):
+                if subString:
+                    if subString[-1] != ".":
+                        subString += "."
+                    _speak(subString, acss, interrupt)
+                    subString = None
+            elif isinstance(element, speech_generator.LineBreak):
+                if subString:
+                    _speak(subString, acss, interrupt)
+                    subString = None
+            elif isinstance(element, sound.Sound):
+                if subString:
+                    _speak(subString, acss, interrupt)
+                    subString = None
+                element.play()
+            else:
+                if subString:
+                    _speak(subString, acss, interrupt)
+                subString = None
+                if isinstance(element, list):
+                    speak(element, acss, interrupt)
+                elif isinstance(element, ACSS):
+                    acss = ACSS(acss)
+                    acss.update(element)
+                else:
+                    debug.println(debug.LEVEL_WARNING,
+                                  "UNKNOWN speech element: '%s'" % element)
+    elif isinstance(content, sound.Sound):
+        content.play()
+    elif isinstance(content, (speech_generator.Pause,
+                              speech_generator.LineBreak)):
+        pass
+    else:
+        debug.printStack(debug.LEVEL_WARNING)
+        debug.println(debug.LEVEL_WARNING, 
+                      "bad content sent to speech.speak: '%s'" % repr(content))
 
-    logLine = "SPEECH OUTPUT: '" + text + "'"
-    debug.println(debug.LEVEL_INFO, logLine)
-    log.info(logLine)
-
-    if _speechserver:
-        _speechserver.speak(text, __resolveACSS(acss), interrupt)
+    if subString:
+        _speak(subString, acss, interrupt)
 
 def speakKeyEvent(event_string, eventType):
     """Speaks a key event immediately.
@@ -238,47 +291,6 @@ def isSpeaking():
     else:
         return False
 
-def speakUtterances(utterances, acss=None, interrupt=True):
-    """Speaks the given list of utterances immediately.
-
-    Arguments:
-    - list:      list of strings to be spoken
-    - acss:      acss.ACSS instance; if None,
-                 the default voice settings will be used.
-                 Otherwise, the acss settings will be
-                 used to augment/override the default
-                 voice settings.
-    - interrupt: if True, stop any speech currently in progress.
-    """
-
-    # We will not interrupt a key echo in progress.
-    #
-    if orca_state.lastKeyEchoTime:
-        interrupt = interrupt \
-            and ((time.time() - orca_state.lastKeyEchoTime) > 0.5)
-
-    if settings.silenceSpeech:
-        return
-    i = 0
-    length = len(utterances)
-    while ( i < length ):
-        if settings.speakMultiCaseStringsAsWords:
-            utterances[i] = _processMultiCaseString(utterances[i])
-        if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            utterances[i] = orca_state.activeScript.adjustForPronunciation(\
-                            utterances[i])
-        if settings.speakMultiCaseStringsAsWords:
-            utterances[i] = _processMultiCaseString(utterances[i])
-        logLine = "SPEECH OUTPUT: '" + utterances[i] + "'"
-        debug.println(debug.LEVEL_INFO, logLine)
-        log.info(logLine)
-        i = i + 1
-
-    if _speechserver:
-        _speechserver.speakUtterances(utterances,
-                                       __resolveACSS(acss),
-                                       interrupt)
-
 def getInfo():
     info = None
     if _speechserver:
